| Title: | R Client for the SENDINBLUE API |
|---|---|
| Description: | Provides an R client for the sendinblue API <https://developers.sendinblue.com>. |
| Authors: | Nicolas Casajus [aut, cre] (ORCID: <https://orcid.org/0000-0002-5537-5294>) |
| Maintainer: | Nicolas Casajus <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-26 10:22:40 UTC |
| Source: | https://github.com/FRBCesab/rsendinblue |
This function prints a simple message. This is a demo function to show good
practices in writing and documenting R function. If you delete this function
do not forget to delete the corresponding test file
tests/testthat/test-demo.R if you used new_package(test = TRUE).
print_msg(x = "Hello world")print_msg(x = "Hello world")
x |
a character of length 1. Default is |
The value of x (only if the result is assigned to a variable).
print_msg() print_msg("Bonjour le monde") x <- print_msg("Bonjour le monde") xprint_msg() print_msg("Bonjour le monde") x <- print_msg("Bonjour le monde") x